==> datanucleus-core-5.0.6-sources.jar: org/datanucleus/store/types/converters/OffsetDateTimeStringConverter.java <==
/**********************************************************************
Copyright (c) 2012 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.store.types.converters;

import java.time.OffsetDateTime;

import org.datanucleus.store.types.converters.ColumnLengthDefiningTypeConverter;
import org.datanucleus.store.types.converters.TypeConverter;

/**
 * Class to handle the conversion between java.time.OffsetDateTime and a String form.
 */
public class OffsetDateTimeStringConverter implements TypeConverter<OffsetDateTime, String>, ColumnLengthDefiningTypeConverter
{
    private static final long serialVersionUID = -2300431146181867887L;

    public OffsetDateTime toMemberType(String str)
    {
        if (str == null)
        {
            return null;
        }

        return OffsetDateTime.parse(str);
    }

    public String toDatastoreType(OffsetDateTime date)
    {
        return date != null ? date.toString() : null;
    }

    public int getDefaultColumnLength(int columnPosition)
    {
        if (columnPosition != 0)
        {
            return -1;
        }
        // Persist as "yyyy-MM-ddThh:mm:ss" when stored as string
        // TODO What if toString() gives "yyyy-MM-dd'T'HH:mm:ssfnnnnnnnnn" ?
        return 19;
    }
}

==> datanucleus-core-5.2.3-sources.jar: org/datanucleus/store/types/converters/OffsetDateTimeStringConverter.java <==
/**********************************************************************
Copyright (c) 2012 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.store.types.converters;

import java.time.OffsetDateTime;
import java.time.format.DateTimeParseException;

import org.datanucleus.exceptions.NucleusDataStoreException;
import org.datanucleus.util.Localiser;

/**
 * Class to handle the conversion between java.time.OffsetDateTime and a String form.
 */
public class OffsetDateTimeStringConverter implements TypeConverter<OffsetDateTime, String>, ColumnLengthDefiningTypeConverter
{
    private static final long serialVersionUID = -2300431146181867887L;

    public OffsetDateTime toMemberType(String str)
    {
        if (str == null)
        {
            return null;
        }

        try
        {
            return OffsetDateTime.parse(str);
        }
        catch (DateTimeParseException pe)
        {
            throw new NucleusDataStoreException(Localiser.msg("016002", str, OffsetDateTime.class.getName()), pe);
        }
    }

    public String toDatastoreType(OffsetDateTime date)
    {
        return date != null ? date.toString() : null;
    }

    public int getDefaultColumnLength(int columnPosition)
    {
        if (columnPosition != 0)
        {
            return -1;
        }
        // Persist as "yyyy-MM-ddThh:mm:ss" when stored as string
        // TODO What if toString() gives "yyyy-MM-dd'T'HH:mm:ssfnnnnnnnnn" ?
        return 19;
    }
}
